@@ -22,13 +22,23 @@ cpp11::strings read_chr(vroom_vec_info* info) {
 
   cpp11::unwind_protect([&] {
     auto i = 0;
-    for (const auto& str : *info->column) {
-      auto val = info->locale->encoder_.makeSEXP(str.begin(), str.end(), false);
+    auto col = info->column;
+    for (auto b = col->begin(), e = col->end(); b != e; ++b) {
+      auto str = *b;
+      auto val = info->locale->encoder_.makeSEXP(str.begin(), str.end(), true);
+      PROTECT(val);
+      if (Rf_xlength(val) < str.end() - str.begin()) {
+        info->errors->add_error(
+            b.index(), col->get_index(), "", "embedded null", b.filename());
+      }
 
       SET_STRING_ELT(out, i++, check_na(nas, val));
+      UNPROTECT(1);
     }
   });
 
+  info->errors->warn_for_errors();
+
   return out;
 }
 
