@@ -2,6 +2,7 @@
 
 #include "altrep.h"
 #include "parallel.h"
+#include "r_utils.h"
 #include "vroom_vec.h"
 
 double bsd_strtod(const char* begin, const char* end, const char decimalMark);
@@ -37,7 +38,7 @@ public:
   static Rboolean
   Inspect(SEXP x, int, int, int, void (*)(SEXP, int, int, int)) {
     Rprintf(
-        "vroom_dbl (len=%d, materialized=%s)\n",
+        "vroom_dbl (len=%" R_PRIdXLEN_T ", materialized=%s)\n",
         Length(x),
         R_altrep_data2(x) != R_NilValue ? "T" : "F");
     return TRUE;
@@ -54,7 +55,7 @@ public:
 
     auto& info = vroom_vec::Info(vec);
     double out = parse_value<double>(
-        info.column->begin() + i,
+        i,
         info.column,
         [&](const char* begin, const char* end) -> double {
           return bsd_strtod(begin, end, info.locale->decimalMark_[0]);
@@ -83,7 +84,7 @@ public:
   }
 
   static void* Dataptr(SEXP vec, Rboolean) {
-    return STDVEC_DATAPTR(Materialize(vec));
+    return DATAPTR_RW(Materialize(vec));
   }
 
   // -------- initialize the altrep class with the methods above
