@@ -3,6 +3,7 @@
 #include <cpp11/doubles.hpp>
 #include <cpp11/integers.hpp>
 
+#include "r_utils.h"
 #include "vroom.h"
 #include "vroom_vec.h"
 
@@ -65,7 +66,7 @@ public:
   static Rboolean
   Inspect(SEXP x, int, int, int, void (*)(SEXP, int, int, int)) {
     Rprintf(
-        "vroom_dttm (len=%d, materialized=%s)\n",
+        "vroom_dttm (len=%" R_PRIdXLEN_T ", materialized=%s)\n",
         Length(x),
         R_altrep_data2(x) != R_NilValue ? "T" : "F");
     return TRUE;
@@ -209,7 +210,7 @@ public:
   }
 
   static void* Dataptr(SEXP vec, Rboolean) {
-    return STDVEC_DATAPTR(Materialize(vec));
+    return DATAPTR_RW(Materialize(vec));
   }
 
   // -------- initialize the altrep class with the methods above
