@@ -2,6 +2,7 @@
 
 #include <cpp11/doubles.hpp>
 
+#include "r_utils.h"
 #include "vroom.h"
 #include "vroom_dttm.h"
 
@@ -47,7 +48,7 @@ public:
   static Rboolean
   Inspect(SEXP x, int, int, int, void (*)(SEXP, int, int, int)) {
     Rprintf(
-        "vroom_time (len=%d, materialized=%s)\n",
+        "vroom_time (len=%" R_PRIdXLEN_T ", materialized=%s)\n",
         Length(x),
         R_altrep_data2(x) != R_NilValue ? "T" : "F");
     return TRUE;
@@ -67,7 +68,7 @@ public:
                        : std::string("time like ") + info->info->format;
 
     double out = parse_value<double>(
-        info->info->column->begin() + i,
+        i,
         info->info->column,
         [&](const char* begin, const char* end) -> double {
           return parse_time(begin, end, *info->parser, info->info->format);
@@ -101,7 +102,7 @@ public:
   }
 
   static void* Dataptr(SEXP vec, Rboolean) {
-    return STDVEC_DATAPTR(Materialize(vec));
+    return DATAPTR_RW(Materialize(vec));
   }
 
   // -------- initialize the altrep class with the methods above
